/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.chart;

import org.jfree.chart.JFreeChart;

/**
 * @author Jacob von Eyben - Nordija A/S
 */
public interface IJFreeChartProvider {
    int JPEG = 0;
    int PNG = 1;

    /**
     * The actual chart to render
     *
     * @return an instance of the JFreeChart you want to render
     */
    JFreeChart getChart();

    /**
     * The height of the chart.
     *
     * @return the height in pixels
     */
    int getHeight();

    /**
     * The width of the chart.
     *
     * @return the width in pixels
     */
    int getWidth();

    /**
     * Tells how to render the chart.
     * Possible return values:
     * <ul>
     * <li>{@link IJFreeChartProvider#JPEG}</li>
     * <li>{@link IJFreeChartProvider#PNG}</li>
     * </ul>
     *
     * @return int value indicating how to render the chart
     */
    int renderAs();
}
