/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.delegate;

import org.apache.tapestry.IBinding;
import org.apache.tapestry.IMarkupWriter;
import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.form.IFormComponent;
import org.apache.tapestry.form.validator.Required;
import org.apache.tapestry.valid.IValidator;
import org.apache.tapestry.valid.ValidationDelegate;

import java.util.Collection;
import java.util.Map;

/**
 * <p>This validation delegate automatically marks required fields with a '!' mark and a 'required' css class to the
 * marker.</p>
 * <p>At the same time it overwrites the default marking of fields in error. Only one * is added and it uses a css class
 * 'error' to mark the single star.</p>
 *
 * @author Jacob von Eyben www.nordija.com
 * @version $Id: ClickOnce.java 93 2007-05-19 09:21:20Z jeyben $
 * @since 2.0.0
 */
public class RequiredValidationDelegate extends ValidationDelegate {

    public void writeSuffix(IMarkupWriter writer, IRequestCycle cycle, IFormComponent component, IValidator validator) {
        if (isInError()) {
            writer.printRaw("&nbsp;");
            writer.begin("span");
            writer.attribute("class", "error");
            writer.print("!");
            writer.end();
        } else if (isRequired(component)) {
            writer.printRaw("&nbsp;");
            writer.begin("span");
            writer.attribute("class", "required");
            writer.print("*");
            writer.end();
        }

    }


    /**
     * Determines if a {@link IFormComponent} has a required validator associated.
     *
     * @param component the {@link IFormComponent} to investigate for required validators.
     * @return <code>true</code> if the {@link IFormComponent} is required, <code>false</code> otherwise.
     */
    private boolean isRequired(IFormComponent component) {
        Map bindings = component.getBindings();
        IBinding validationBinding = (IBinding) bindings.get("validators");
        boolean required = false;
        if (validationBinding != null) {
            Object validationBindingObject = validationBinding.getObject();
            if (validationBindingObject != null && validationBindingObject instanceof Collection) {
                Collection validators = (Collection) validationBindingObject;
                for (java.util.Iterator iterator = validators.iterator(); iterator.hasNext();) {
                    Object aValidator = iterator.next();
                    if (aValidator instanceof Required) {
                        required = true;
                        break;
                    }
                }
            }
        }
        return required;
    }
}
