/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.downloads;

import org.apache.tapestry.IMarkupWriter;
import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.engine.IEngineService;
import org.apache.tapestry.engine.ILink;
import org.apache.tapestry.link.AbstractLinkComponent;

/**
 * Renders a link to the stream service.
 * <p/>
 * The link will include an id for the resource to be streamed.
 *
 * @author Per Olesen www.nordija.com
 * @author Jacob von Eyben www.nordija.com
 * @version $Id: DownloadLink.java 119 2007-06-01 12:46:54Z jeyben $
 * @see com.nordija.tapestry.bayeux.stream.StreamLink
 * @see com.nordija.tapestry.bayeux.stream.StreamService
 * @deprecated Will moste likly be removed in a later release. Use the {@link com.nordija.tapestry.bayeux.stream.StreamLink} instead.
 */
public abstract class DownloadLink extends AbstractLinkComponent {

    public abstract String getDownloadResourceId();

    public abstract String getDownloadResourceSourceExtentionName();

    public abstract boolean isStateful();

    public abstract IEngineService getDownloadService();

    protected void renderComponent(IMarkupWriter writer, IRequestCycle cycle) {
        if (cycle.isRewinding()) {
            return;
        }

        ILink link = getDownloadService().getLink(isStateful(), new Object[]{getDownloadResourceId(), getDownloadResourceSourceExtentionName()});

        if (!isDisabled()) {
            writer.begin("a");
            writer.attribute("href", link.getURL());
            renderInformalParameters(writer, cycle);
        }
        renderBody(writer, cycle);
        if (!isDisabled()) {
            writer.end();
        }
    }

}