/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.insert;

import org.apache.hivemind.ApplicationRuntimeException;
import org.apache.tapestry.IMarkupWriter;
import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.components.Insert;

import java.text.Format;

/**
 * Outputs a limited string from the underlying object. Works as Insert.
 *
 * @author Thomas Christensen www.nordija.com
 * @version $Id$
 */
public abstract class InsertLimited extends Insert {

    public abstract int getMaxLength();

    public abstract String getMoreMarker();

    /**
     * Prints its value parameter, possibly formatted by its format parameter.
     */
    protected void renderComponent(IMarkupWriter writer, IRequestCycle cycle) {
        if (cycle.isRewinding())
            return;

        Object value = getValue();

        if (value == null)
            return;

        String insert;

        Format format = getFormat();

        if (format == null) {
            insert = value.toString();
        } else {
            try {
                insert = format.format(value);
            }
            catch (Exception ex) {
                throw new ApplicationRuntimeException(InsertMessages.unableToFormat(this, value, ex), this, getBinding(
                        "format").getLocation(), ex);
            }
        }

        //added to be able to insert a limited amount of text
        if (!getRaw() && insert.length() > getMaxLength()) {
            if (getMoreMarker() == null) {
                insert = insert.substring(0, getMaxLength());
            } else {
                insert = insert.substring(0, getMaxLength() - getMoreMarker().length()) + getMoreMarker();
            }
        }

        boolean render = getRenderTag() || isParameterBound("class");

        if (render) {
            writer.begin(getTemplateTagName());

            renderInformalParameters(writer, cycle);
        }

        printText(writer, cycle, insert);

        if (render) {
            writer.end();
        }
    }
}