/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.stream;

import org.apache.hivemind.Location;
import org.apache.hivemind.Resource;
import org.apache.tapestry.IAsset;
import org.apache.tapestry.engine.IEngineService;
import org.apache.tapestry.engine.ILink;
import org.apache.tapestry.link.DirectLink;

import java.io.InputStream;

/**
 * Asset capable of streaming data by invoking the stream service that will delegate the responsibility to the
 * given streamResourceSourceExtentionName.
 * @author Jacob von Eyben - Nordija A/S
 */
public class StreamAsset implements IAsset {

    private IEngineService streamService;
    private String streamResourceSourceExtentionName;
    private Object[] parameters;
    private IStream stream;

    public StreamAsset(IEngineService streamService, String streamResourceSourceExtentionName, Object[] parameters, IStream stream) {
        this.streamService = streamService;
        this.streamResourceSourceExtentionName = streamResourceSourceExtentionName;
        this.parameters = parameters;
        this.stream = stream;
    }

    public String buildURL() {
        return getLink().getURL();
    }

    public InputStream getResourceAsStream() {
        throw new UnsupportedOperationException("getResourceAsStream is not supported by the StreamAsset. Only use buildURL on a StreamAsset");
    }

    public Resource getResourceLocation() {
        throw new UnsupportedOperationException("getResourceLocation is not supported by the StreamAsset. Only use buildURL on a StreamAsset");
    }

    public Location getLocation() {
        throw new UnsupportedOperationException("getLocation is not supported by the StreamAsset. Only use buildURL on a StreamAsset");
    }

    protected ILink getLink() {
        Object[] serviceParameters = DirectLink.constructServiceParameters(parameters);
        StreamServiceParameter ssp = new StreamServiceParameter(stream, streamResourceSourceExtentionName, serviceParameters);
        return streamService.getLink(stream.isStateful(), ssp);
    }

}
