/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.stream;

import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.engine.IEngineService;
import org.apache.tapestry.engine.ILink;
import org.apache.tapestry.link.AbstractLinkComponent;
import org.apache.tapestry.link.DirectLink;

/**
 * Renders a link to the stream service.
 * <p/>
 * The link acts much like the {@link DirectLink} but renders a link to the {@link StreamService}  an id for the resource to be streamed.
 *
 * @author Jacob von Eyben www.nordija.com
 * @version $Id: StreamLink.java 131 2007-06-05 19:31:21Z jeyben $
 * @see com.nordija.tapestry.bayeux.stream.StreamService
 */
public abstract class StreamLink extends AbstractLinkComponent implements IStream {

    /**
     * The parameters passed to the StreamService and further to the specified StreamResourceSourceExtention.
     *
     * @return
     */
    public abstract Object getParameters();

    /**
     * todo: document
     *
     * @return
     */
    public abstract String getStreamResourceSourceExtentionName();

    /**
     * todo: document
     *
     * @return
     */
    public abstract IEngineService getStreamService();

    /**
     * todo: document
     *
     * @param cycle
     * @return
     */
    public ILink getLink(IRequestCycle cycle) {
        Object[] serviceParameters = DirectLink.constructServiceParameters(getParameters());
        StreamServiceParameter ssp = new StreamServiceParameter(this, getStreamResourceSourceExtentionName(), serviceParameters);
        return getStreamService().getLink(isStateful(), ssp);
    }
}
