/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.stream;

import org.apache.tapestry.IRequestCycle;

import java.io.IOException;

import com.nordija.tapestry.bayeux.stream.StreamResource;

/**
 * A source for resources that can be downloaded by the bayeux downloads service.
 * <p/>
 * An implementation of this interface must be configured in the application using the
 * bayeux downloads service as an extension.
 * The downloads service will ask the defined implementation for a resource based on an
 * id when links are clicked.
 *
 * @see com.nordija.tapestry.bayeux.stream.StreamService
 * @author Per Olesen www.nordija.com
 * @version $Id: StreamResourceSource.java 119 2007-06-01 12:46:54Z jeyben $
 */
public interface StreamResourceSource {

    /**
     * Called by downloads service when a download link has been clicked
     * and the resource to be downloaded is to be obtained from somewhere.
     *
     * @param cycle       the request cycle which originated the incoming request for a download resource
     * @param parameters  the parameters used to find and generate the needed stream resource
     * @return an instance of the resource identified by the given id or null if resource not found
     * @throws IOException if obtaining the resource fails with an exception (no resource on id should not result in this exception!)
     */
    StreamResource getStreamResource(IRequestCycle cycle, Object[] parameters) throws IOException;
}
