/*
 * Copyright 2004 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.nordija.tapestry.bayeux.stream;

import org.apache.hivemind.util.Defense;
import org.apache.tapestry.IDynamicInvoker;

import java.util.Collection;

/**
 * @author Jacob von Eyben - Nordija A/S
 */
public class StreamServiceParameter {

    private IStream stream;

    private String streamResourceSourceExtentionName;

    private Object[] serviceParameters;

    private String[] updateParts;

    private boolean json;

    private boolean async;

    public StreamServiceParameter(IStream stream, String streamResourceSourceExtentionName, Object[] serviceParameters) {
        this(stream, streamResourceSourceExtentionName, serviceParameters, null);
    }

    public StreamServiceParameter(IStream stream, String streamResourceSourceExtentionName, Object[] serviceParameters, IDynamicInvoker invoker) {
        Defense.notNull(stream, "stream");
        this.stream = stream;
        this.serviceParameters = serviceParameters;
        this.streamResourceSourceExtentionName = streamResourceSourceExtentionName;

        if (invoker == null) {

            Collection comps = stream.getUpdateComponents();
            if (comps == null)
                updateParts = new String[0];
            else
                updateParts = (String[]) comps.toArray(new String[comps.size()]);

            json = stream.isJson();
            async = stream.isAsync();
        } else {

            Collection comps = invoker.getUpdateComponents();
            if (comps == null)
                updateParts = new String[0];
            else
                updateParts = (String[]) comps.toArray(new String[comps.size()]);

            json = invoker.isJson();
            async = invoker.isAsync();
        }

        // if they gave only an updateComponents param make it async by default
        if (!json && !async && updateParts.length > 0)
            async = true;

    }

    public IStream getStream() {
        return stream;
    }

    public String getStreamResourceSourceExtentionName() {
        return streamResourceSourceExtentionName;
    }

    public Object[] getServiceParameters() {
        return serviceParameters;
    }

    public String[] getUpdateParts() {
        return updateParts;
    }

    public boolean isJson() {
        return json;
    }

    public boolean isAsync() {
        return async;
    }
}
